aboutsummaryrefslogtreecommitdiffhomepage
path: root/include/gpu/GrGpuResource.h
diff options
context:
space:
mode:
authorGravatar bsalomon <bsalomon@google.com>2015-01-23 12:47:59 -0800
committerGravatar Commit bot <commit-bot@chromium.org>2015-01-23 12:47:59 -0800
commit63c992f6c05ea728b5386de61d279f10eb7e08d9 (patch)
tree0ca9b96baedd9525e4def9a7dd9651c9dd773b47 /include/gpu/GrGpuResource.h
parent6a144345d742a53ffb15bbd83f2718022fca8df5 (diff)
Fix the speeling of "purgeable" in Gr code
TBR=robertphillips@google.com Review URL: https://codereview.chromium.org/874693002
Diffstat (limited to 'include/gpu/GrGpuResource.h')
-rw-r--r--include/gpu/GrGpuResource.h10
1 files changed, 5 insertions, 5 deletions
diff --git a/include/gpu/GrGpuResource.h b/include/gpu/GrGpuResource.h
index 56b73a0f07..bdf6257d4d 100644
--- a/include/gpu/GrGpuResource.h
+++ b/include/gpu/GrGpuResource.h
@@ -34,7 +34,7 @@ class GrResourceCache2;
*
* The latter two ref types are private and intended only for Gr core code.
*
* When an item is purgable DERIVED:notifyIsPurgable() will be called (static poly morphism using
* CRTP). GrIORef and GrGpuResource are separate classes for organizational reasons and to be
* able to give access via friendship to only the functions related to pending IO operations.
*/
@@ -69,7 +69,7 @@ public:
protected:
GrIORef() : fRefCnt(1), fPendingReads(0), fPendingWrites(0) { }
- bool isPurgable() const { return !this->internalHasRef() && !this->internalHasPendingIO(); }
+ bool isPurgeable() const { return !this->internalHasRef() && !this->internalHasPendingIO(); }
bool internalHasPendingRead() const { return SkToBool(fPendingReads); }
bool internalHasPendingWrite() const { return SkToBool(fPendingWrites); }
@@ -103,7 +103,7 @@ private:
private:
void didUnref() const {
if (0 == fPendingReads && 0 == fPendingWrites && 0 == fRefCnt) {
- static_cast<const DERIVED*>(this)->notifyIsPurgable();
+ static_cast<const DERIVED*>(this)->notifyIsPurgeable();
}
}
@@ -260,7 +260,7 @@ private:
// See comments in CacheAccess.
bool setContentKey(const GrContentKey& contentKey);
- void notifyIsPurgable() const;
+ void notifyIsPurgeable() const;
void removeScratchKey();
void makeBudgeted();
void makeUnbudgeted();
@@ -290,7 +290,7 @@ private:
SkAutoTUnref<const SkData> fData;
typedef GrIORef<GrGpuResource> INHERITED;
- friend class GrIORef<GrGpuResource>; // to access notifyIsPurgable.
+ friend class GrIORef<GrGpuResource>; // to access notifyIsPurgeable.
};
#endif
@@ -34,7 +34,7 @@ class GrResourceCache2;
* The latter two ref types are private and intended only for Gr core code.
*
- * When an item is purgable DERIVED:notifyIsPurgable() will be called (static poly morphism using
+ * When an item is purgeable DERIVED:notifyIsPurgeable() will be called (static poly morphism using
* CRTP). GrIORef and GrGpuResource are separate classes for organizational reasons and to be
* able to give access via friendship to only the functions related to pending IO operations.